---
title: Overview
template: home.html
---

<!-- # Getting started

{{rbx}} is a CLI tool and library that aims to help setters from the competitive programming community to have an easier time.

A flexible setting tool, as powerful as {{polygon}}, right on your terminal.

## Features

- 🧱 Structure: describe your problem or contest structure with the use of YAML configuration files.
- 🤖 Generation: provides a simple way to describe your whole testset, including both manually added and generated testcases.
- 🔨 Testing: provides commands for automatically running correct and incorrect solutions against the testcases of your problem, automatically judging whether the verdict was as expected or not.
- ✅ Verify: checks if your testcases and solutions are strictly conformant with the use of validators and unit tests.
- 📝 Statements: provides tooling for writing and building statements, also ensuring they're easily synchronized with your testset.
- 📤 Package: provides a single command for packaging your problems for use in your preferred judge system.

---

Proceed to the [Installation](intro/installation.md) section. -->
